@@ -99,7 +99,19 @@ def mask_function_for_bug(shape, ci_frame):
 
 from workspace_jam.pipelines.initialize import parallel_x2
 
-pipeline = parallel_x2.make_pipeline(phase_folders=[ci_data_type, ci_data_model, ci_data_resolution],
-                                      mask_function=mask_function_for_bug)
+pipeline_init = parallel_x2.make_pipeline(phase_folders=[ci_data_type, ci_data_model, ci_data_resolution],
+                                     mask_function=mask_function_for_bug)
+
+from workspace_jam.pipelines.normal.from_initialize import parallel_x2
+
+pipeline_normal = parallel_x2.make_pipeline(phase_folders=[ci_data_type, ci_data_model, ci_data_resolution],
+                                     mask_function=mask_function_for_bug)
+
+instance = pipeline_normal.phases[0].variable.instance_from_physical_vector(physical_vector=[0.5, 0.5, 0.5, 0.5, 0.6, 0.7, 0.8, 0.9])
+print(instance.parallel_ccd.well_fill_alpha)
+print(instance.parallel_ccd.well_fill_beta)
+print(instance.parallel_ccd.well_fill_gamma)
+stop
+pipeline = pipeline_init + pipeline_normal
 
 pipeline.run(ci_datas=datas, cti_settings=cti_settings, pool=Pool(processes=2), assert_optimizer_pickle_matches=False)
\ No newline at end of file
