@@ -8,10 +8,11 @@ workspace_path = '{}/../'.format(os.path.dirname(os.path.realpath(__file__)))
 # Use this path to explicitly set the config path and output path.
 conf.instance = conf.Config(config_path=workspace_path + 'config', output_path=workspace_path + 'output')
 
-agg = aggregator.Aggregator(directory=workspace_path + 'output')
+pipeline = 'pipeline_init__parallel_x2 + pipeline_normal__parallel_x2'
+phase = 'phase_1_parallel_x2'
 
-pipeline = 'pipeline_parallel_x2_species'
-phase = 'phase_4_final'
+agg = aggregator.Aggregator(directory=workspace_path + 'output/ci_images_uniform/parallel_x2/high_resolution/')
 
-# print(agg.phases_with(pipeline=pipeline, phase=phase))
-print(agg.model_results(pipeline=pipeline, phase=phase))
\ No newline at end of file
+opt = agg.optimizers_with(pipeline=pipeline, phase=phase)
+
+print(opt)
\ No newline at end of file
